@@ -248,23 +248,24 @@ FlatpakResource * FlatpakBackend::getAppForInstalledRef(FlatpakInstallation *fla
     if (!r)
         r = m_resources.value(idForInstalledRef(flatpakInstallation, ref, QStringLiteral(".desktop")));
 
-    if (!r) {
-        qDebug() << "no" << flatpak_ref_get_name(FLATPAK_REF(ref));
-    }
+//     if (!r) {
+//         qDebug() << "no" << flatpak_ref_get_name(FLATPAK_REF(ref));
+//     }
     return r;
 }
 
 FlatpakResource * FlatpakBackend::getRuntimeForApp(FlatpakResource *resource) const
 {
     FlatpakResource *runtime = nullptr;
-    const auto runtimeInfo = resource->runtime().split(QLatin1Char('/'));
+    const QString runtimeName = resource->runtime();
+    const auto runtimeInfo = runtimeName.splitRef(QLatin1Char('/'));
 
     if (runtimeInfo.count() != 3) {
         return runtime;
     }
 
     for(auto it = m_resources.constBegin(), itEnd = m_resources.constEnd(); it!=itEnd; ++it) {
-        const auto id = it.key();
+        const auto& id = it.key();
         if (id.type == FlatpakResource::Runtime && id.id == runtimeInfo.at(0) && id.branch == runtimeInfo.at(2)) {
             runtime = *it;
             break;
@@ -736,7 +737,8 @@ bool FlatpakBackend::loadInstalledApps(FlatpakInstallation *flatpakInstallation)
         const QString fnDesktop = pathApps + name + QLatin1String(".desktop");
         AppStream::Metadata::MetadataError error = metadata.parseFile(fnDesktop, AppStream::Metadata::FormatKindDesktopEntry);
         if (error != AppStream::Metadata::MetadataErrorNoError) {
-            qDebug() << "Failed to parse appstream metadata:" << error << fnDesktop;
+            if (QFile::exists(fnDesktop))
+                qDebug() << "Failed to parse appstream metadata:" << error << fnDesktop;
 
             cid.setId(QString::fromLatin1(flatpak_ref_get_name(FLATPAK_REF(ref))));
 #if FLATPAK_CHECK_VERSION(1,1,2)
@@ -886,15 +888,16 @@ public:
 #else
         if (!flatpak_installation_update_appstream_sync(m_installation, flatpak_remote_get_name(m_remote), nullptr, nullptr, m_cancellable, &localError)) {
 #endif
-            qWarning() << "Failed to refresh appstream metadata for " << flatpak_remote_get_name(m_remote) << ": " << (localError ? localError->message : "<no error>");
-            Q_EMIT jobRefreshAppstreamMetadataFailed();
+            const QString error = localError ? QString::fromUtf8(localError->message) : QStringLiteral("<no error>");
+            qWarning() << "Failed to refresh appstream metadata for " << flatpak_remote_get_name(m_remote) << ": " << error;
+            Q_EMIT jobRefreshAppstreamMetadataFailed(error);
         } else  {
             Q_EMIT jobRefreshAppstreamMetadataFinished(m_installation, m_remote);
         }
     }
 
 Q_SIGNALS:
-    void jobRefreshAppstreamMetadataFailed();
+    void jobRefreshAppstreamMetadataFailed(const QString &errorMessage);
     void jobRefreshAppstreamMetadataFinished(FlatpakInstallation *installation, FlatpakRemote *remote);
 
 private:
@@ -907,6 +910,7 @@ void FlatpakBackend::refreshAppstreamMetadata(FlatpakInstallation *installation,
 {
     FlatpakRefreshAppstreamMetadataJob *job = new FlatpakRefreshAppstreamMetadataJob(installation, remote);
     connect(job, &FlatpakRefreshAppstreamMetadataJob::jobRefreshAppstreamMetadataFailed, this, &FlatpakBackend::metadataRefreshed);
+    connect(job, &FlatpakRefreshAppstreamMetadataJob::jobRefreshAppstreamMetadataFailed, this, [this] (const QString &errorMessage) { Q_EMIT passiveMessage(errorMessage); });
     connect(job, &FlatpakRefreshAppstreamMetadataJob::jobRefreshAppstreamMetadataFinished, this, &FlatpakBackend::integrateRemote);
     connect(job, &FlatpakRefreshAppstreamMetadataJob::finished, this, [this] { acquireFetching(false); });
 
