@@ -30,27 +30,6 @@ Q_GLOBAL_STATIC(SourcesModel, s_sources)
 const auto DisplayName = "DisplayName";
 const auto SourcesBackendId = "SourcesBackend";
 
-class SourceBackendModel : public QAbstractListModel
-{
-Q_OBJECT
-public:
-    SourceBackendModel(AbstractResourcesBackend* backend)
-        : QAbstractListModel(backend), m_backend(backend)
-    {}
-
-    QVariant data(const QModelIndex & index, int role) const override {
-        if (!index.isValid()) return {};
-        switch(role) {
-            case SourcesModel::ResourcesBackend: return QVariant::fromValue<QObject*>(m_backend);
-        }
-        return {};
-    }
-    int rowCount(const QModelIndex & parent) const override { return parent.isValid() ? 0 : 1; }
-
-private:
-    AbstractResourcesBackend* m_backend;
-};
-
 SourcesModel::SourcesModel(QObject* parent)
     : KConcatenateRowsProxyModel(parent)
 {}
@@ -69,6 +48,7 @@ QHash<int, QByteArray> SourcesModel::roleNames() const
     roles.insert(SourceNameRole, "sourceName");
     roles.insert(SourcesBackend, "sourcesBackend");
     roles.insert(ResourcesBackend, "resourcesBackend");
+    roles.insert(EnabledRole, "enabled");
     return roles;
 }
 
@@ -78,8 +58,11 @@ void SourcesModel::addSourcesBackend(AbstractSourcesBackend* sources)
 
     auto m = sources->sources();
     m->setProperty(DisplayName, backend->displayName());
-    m->setProperty(SourcesBackendId, qVariantFromValue<QObject*>(sources));
+    m->setProperty(SourcesBackendId, QVariant::fromValue<QObject*>(sources));
     addSourceModel(m);
+
+    if (!m->rowCount())
+        qWarning() << "adding empty sources model" << m;
 }
 
 const QAbstractItemModel * SourcesModel::modelAt(const QModelIndex& index) const
@@ -96,6 +79,8 @@ QVariant SourcesModel::data(const QModelIndex& index, int role) const
             return modelAt(index)->property(DisplayName);
         case SourcesBackend:
             return modelAt(index)->property(SourcesBackendId);
+        case EnabledRole:
+            return QVariant(flags(index) & Qt::ItemIsEnabled);
         default:
             return KConcatenateRowsProxyModel::data(index, role);
     }
@@ -111,5 +96,3 @@ AbstractSourcesBackend * SourcesModel::sourcesBackendByName(const QString& id) c
     }
     return nullptr;
 }
-
-#include "SourcesModel.moc"
